@@ -375,7 +375,7 @@ llognormgpd <- function(x, lnmean = 0, lnsd = 1, u = qlnorm(0.9, lnmean, lnsd),
     syu = 1 + xi * (xu - u) / sigmau  
     yb = (log(xb) - lnmean) / lnsd    # used for log-normal
   
-    if ((min(syu) <= 0) | (phiu <= 0) | (phiu >= 1)) {
+    if ((min(syu) <= 0) | (phiu <= 0) | (phiu >= 1) | (pu <= 0) | (pu >= 1)) {
       l = -Inf
     } else { 
       l = lgpd(xu, u, sigmau, xi, phiu)
@@ -427,7 +427,7 @@ nllognormgpd <- function(pvector, x, phiu = TRUE, finitelik = FALSE) {
 # log-normal bulk with GPD for upper tail
 # designed for sapply to loop over vector of thresholds (hence u is first input)
 proflulognormgpd <- function(u, pvector, x, phiu = TRUE, method = "BFGS",
-  control = list(maxit = 10000), finitelik = FALSE, ...) {
+  control = list(maxit = 10000), finitelik = TRUE, ...) {
 
   np = 5 # maximum number of parameters
 
